<?php
require __DIR__.'/../datos/Conexion.clase.php';
require_once __DIR__.'/../util/definiciones.php';
require_once __DIR__ . '/../util/upload/autoload.php';
date_default_timezone_set("America/Lima");

class Accidente extends Conexion {

    public function reportarAccidente($dni, $cod_usu, $caseta, $tipo_caseta, $desc_inc, $foto, $placa)
    {
        $this->dblink->beginTransaction();
        try{
            $sql = "SELECT numero + 1 as nc from correlativo_control where tabla = 'accidente_control';";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->execute();

            if (!$sentencia->rowCount()) {
                $sql = "INSERT into correlativo_control(numero, tabla) values(0, 'accidente_control');";
                $sentencia = $this->dblink->prepare($sql);
                $sentencia->execute();
                $codigo = 1;
            } else {
                $resultado = $sentencia->fetch(PDO::FETCH_ASSOC);
                $codigo = $resultado["nc"];
            }

            $fecha_registro = date("Y-m-d H:i:s");
            $sql = "INSERT into accidente_control(codigo_accidente_control, fecha, descripcion, placa, dni_conductor, codigo_caseta, codigo_usuario, tipo_caseta)
                                    values(?, ?, ?, ?, ?, ?, ?, ?);";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(1, $codigo);
            $sentencia->bindParam(2, $fecha_registro);
            $sentencia->bindParam(3, $desc_inc);
            $sentencia->bindParam(4, $placa);
            $sentencia->bindParam(5, $dni);
            $sentencia->bindParam(6, $caseta);
            $sentencia->bindParam(7, $cod_usu);
            $sentencia->bindParam(8, $tipo_caseta);
            $sentencia->execute();

            $sql = "UPDATE correlativo_control SET numero = numero + 1 where tabla = 'accidente_control'";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->execute();

            if(!empty($foto)){
                $directorio = dirname(__DIR__) . "/fotos/reporte-accidente/garita-principal/" . $this->base64url_encode($caseta);
                if (!file_exists($directorio)) {
                    mkdir($directorio, 0777, true);
                }

                $fecha = date("Y-m-d H:i:s");
                $nombreFoto = $this->base64url_encode($fecha);
                $handle = new upload($foto['p_foto']['tmp_name']);

                if ($handle->uploaded) {
                    $handle->image_convert        = 'png';
                    $handle->file_new_name_ext    = 'png';
                    $handle->file_force_extension = true;
                    $handle->file_new_name_body   = $nombreFoto;
                    $handle->image_resize         = true;
                    $handle->image_ratio          = true;
                    $handle->image_y              = 720;
                    $handle->image_x              = 900;
                    $handle->process($directorio.'/');
                    if ($handle->processed) {
                        $handle->clean();
                        $url_foto = 'https://' . $_SERVER["HTTP_HOST"] . "/fotos/reporte-accidente/garita-principal/" . $this->base64url_encode($caseta) . '/' . $nombreFoto . '.png';

                        $sql = "SELECT numero + 1 as nc from correlativo_control where tabla = 'accidente_control_media';";
                        $sentencia = $this->dblink->prepare($sql);
                        $sentencia->execute();

                        if (!$sentencia->rowCount()) {
                            $sql = "INSERT into correlativo_control(numero, tabla) values(0, 'accidente_control_media');";
                            $sentencia = $this->dblink->prepare($sql);
                            $sentencia->execute();
                            $codigo_media = 1;
                        } else {
                            $resultado = $sentencia->fetch(PDO::FETCH_ASSOC);
                            $codigo_media = $resultado["nc"];
                        }
                        $sql = "INSERT into accidente_control_media (codigo_accidente_control, codigo_media, url_foto)
                                        values (?, ?, ?);";
                        $sentencia = $this->dblink->prepare($sql);
                        $sentencia->bindParam(1, $codigo);
                        $sentencia->bindParam(2, $codigo_media);
                        $sentencia->bindParam(3, $url_foto);
                        $sentencia->execute();

                        $sql = "UPDATE correlativo_control set numero = (numero + 1) where tabla = 'accidente_control_media';";
                        $sentencia = $this->dblink->prepare($sql);
                        $sentencia->execute();
                        $this->dblink->commit();
                        return $url_foto;
                    } else {
                        throw new Exception($handle->error);
                    }
                }else{
                    throw new Exception($handle->error);
                }
            }else{
                $this->dblink->commit();
                return "INFRACCIÓN REPORTADA";
            }
        }catch(Exception $e){
            $this->dblink->rollBack();
            throw $e;
        }
    }

    public function listarAccidentes($codigo_caseta, $tipo_caseta)
    {
        $sql = "SELECT
                        a.codigo_accidente_control,
                        a.fecha,
                        a.descripcion,
                        coalesce(a.placa, '') as placa,
                        COALESCE(a.dni_conductor, '') as dni_conductor,
                        coalesce(
													(case (c.apellidos_paternos_conductor || ' ' || c.apellidos_maternos_conductor || ', ' || c.nombre_conductor) when ' , ' then 'NOMBRE NO REGISTRADO' else (c.apellidos_paternos_conductor || ' ' || c.apellidos_maternos_conductor || ', ' || c.nombre_conductor) end),
													'NOMBRE NO REGISTRADO') as nombre,
                        coalesce(
                            (SELECT
                                url_foto
                            FROM
                                accidente_control_media
                            WHERE
                                codigo_accidente_control = a.codigo_accidente_control
                            LIMIT 1),
                            ''
                        ) as media
                from
                    accidente_control as a
                    left join conductor_control as c on(trim(a.dni_conductor) = trim(c.dni_conductor))
                where
                    a.codigo_caseta = ? and a.tipo_caseta = ?";
        $sentencia = $this->dblink->prepare($sql);
        $sentencia->bindParam(1, $codigo_caseta);
        $sentencia->bindParam(2, $tipo_caseta);
        $sentencia->execute();
        $resultado = $sentencia->fetchAll(PDO::FETCH_ASSOC);
        return $resultado;
    }

    function base64url_encode($data) {
        return rtrim(strtr(base64_encode($data), '+/', '-_'), '=');
    }

    function base64url_decode($data) {
        return base64_decode(str_pad(strtr($data, '-_', '+/'), strlen($data) % 4, '=', STR_PAD_RIGHT));
    }

}