<?php
require __DIR__.'/../datos/Conexion.clase.php';
require_once __DIR__.'/../util/definiciones.php';
require_once __DIR__ . '/../util/upload/autoload.php';
date_default_timezone_set("America/Lima");

class Infraccion extends Conexion {

    public function reportarInfraccion($dni, $cod_usu, $caseta, $tipo_caseta, $desc_inc, $foto)
    {
        $this->dblink->beginTransaction();
        try{
            $sql = "SELECT numero + 1 as nc from correlativo_control where tabla = 'reporte_infraccion_conductor';";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->execute();

            if (!$sentencia->rowCount()) {
                $sql = "INSERT into correlativo_control(numero, tabla) values(0, 'reporte_infraccion_conductor');";
                $sentencia = $this->dblink->prepare($sql);
                $sentencia->execute();
                $codigo = 1;
            } else {
                $resultado = $sentencia->fetch(PDO::FETCH_ASSOC);
                $codigo = $resultado["nc"];
            }

            $fecha_registro = date("Y-m-d H:i:s");
            $sql = "INSERT into reporte_infraccion_conductor(codigo_reporte_infraccion, dni_conductor, codigo_usuario, codigo_caseta, tipo_caseta, descripcion, fecha_registro)
                                    values(?, ?, ?, ?, ?, ?, ?);";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->bindParam(1, $codigo);
            $sentencia->bindParam(2, $dni);
            $sentencia->bindParam(3, $cod_usu);
            $sentencia->bindParam(4, $caseta);
            $sentencia->bindParam(5, $tipo_caseta);
            $sentencia->bindParam(6, $desc_inc);
            $sentencia->bindParam(7, $fecha_registro);
            $sentencia->execute();

            $sql = "UPDATE correlativo_control SET numero = numero + 1 where tabla = 'reporte_infraccion_conductor'";
            $sentencia = $this->dblink->prepare($sql);
            $sentencia->execute();

            if(!empty($foto)){
                $directorio = dirname(__DIR__) . "/fotos/reporte-infraccion/garita-principal/" . $this->base64url_encode($caseta);
                if (!file_exists($directorio)) {
                    mkdir($directorio, 0777, true);
                }

                $fecha = date("Y-m-d H:i:s");
                $nombreFoto = $this->base64url_encode($fecha);
                $handle = new upload($foto['p_foto']['tmp_name']);

                if ($handle->uploaded) {
                    $handle->image_convert        = 'png';
                    $handle->file_new_name_ext    = 'png';
                    $handle->file_force_extension = true;
                    $handle->file_new_name_body   = $nombreFoto;
                    $handle->image_resize         = true;
                    $handle->image_ratio          = true;
                    $handle->image_y              = 720;
                    $handle->image_x              = 900;
                    $handle->process($directorio.'/');
                    if ($handle->processed) {
                        $handle->clean();
                        $url_foto = 'https://' . $_SERVER["HTTP_HOST"] . "/fotos/reporte-infraccion/garita-principal/" . $this->base64url_encode($caseta) . '/' . $nombreFoto . '.png';
                        // $url_foto = 'https://' . $_SERVER["HTTP_HOST"] . "/chino-server/senasa.proolmos.pe/fotos/reporte-infraccion/garita-principal/" . $this->base64url_encode($caseta) . '/' . $nombreFoto . '.png';

                        $sql = "SELECT numero + 1 as nc from correlativo_control where tabla = 'reporte_infraccion_conductor_media';";
                        $sentencia = $this->dblink->prepare($sql);
                        $sentencia->execute();

                        if (!$sentencia->rowCount()) {
                            $sql = "INSERT into correlativo_control(numero, tabla) values(0, 'reporte_infraccion_conductor_media');";
                            $sentencia = $this->dblink->prepare($sql);
                            $sentencia->execute();
                            $codigo_media = 1;
                        } else {
                            $resultado = $sentencia->fetch(PDO::FETCH_ASSOC);
                            $codigo_media = $resultado["nc"];
                        }
                        $sql = "INSERT into reporte_infraccion_conductor_media (codigo_reporte_infraccion, codigo_media, url_foto)
                                        values (?, ?, ?);";
                        $sentencia = $this->dblink->prepare($sql);
                        $sentencia->bindParam(1, $codigo);
                        $sentencia->bindParam(2, $codigo_media);
                        $sentencia->bindParam(3, $url_foto);
                        $sentencia->execute();

                        $sql = "UPDATE correlativo_control set numero = (numero + 1) where tabla = 'reporte_infraccion_conductor_media';";
                        $sentencia = $this->dblink->prepare($sql);
                        $sentencia->execute();
                        $this->dblink->commit();
                        return $url_foto;
                    } else {
                        throw new Exception($handle->error);
                    }
                }else{
                    throw new Exception($handle->error);
                }
            }else{
                $this->dblink->commit();
                return "INFRACCIÓN REPORTADA";
            }
        }catch(Exception $e){
            $this->dblink->rollBack();
            throw $e;
        }
    }

    public function listarInfraccion($tipo_caseta, $p_caseta)
    {
        $sql = "SELECT
                        ri.*,
                        (case (c.apellidos_paternos_conductor || ' ' || c.apellidos_maternos_conductor || ', ' || c.nombre_conductor) when ' , ' then 'NOMBRE NO REGISTRADO' else (c.apellidos_paternos_conductor || ' ' || c.apellidos_maternos_conductor || ', ' || c.nombre_conductor) end) as nombre,
                        coalesce(
                            (SELECT
                                url_foto
                            FROM
                                reporte_infraccion_conductor_media
                            WHERE
                                codigo_reporte_infraccion = ri.codigo_reporte_infraccion
                            LIMIT 1),
                            ''
                        ) as media
                from
                    reporte_infraccion_conductor as ri
                    inner join conductor_control as c on(trim(ri.dni_conductor) = trim(c.dni_conductor))
                where
                    ri.codigo_caseta = ? and ri.tipo_caseta = ?";
        $sentencia = $this->dblink->prepare($sql);
        $sentencia->bindParam(1, $p_caseta);
        $sentencia->bindParam(2, $tipo_caseta);
        $sentencia->execute();
        $resultado = $sentencia->fetchAll(PDO::FETCH_ASSOC);
        return $resultado;
    }

    function base64url_encode($data) {
        return rtrim(strtr(base64_encode($data), '+/', '-_'), '=');
    }

    function base64url_decode($data) {
        return base64_decode(str_pad(strtr($data, '-_', '+/'), strlen($data) % 4, '=', STR_PAD_RIGHT));
    }

}